# Code 3.3   lorenz_attractor.R
#
parms<- c(10,8/3,28) # parameters: sigma, beta, rho
tinit<- 0
tfin<- 100
step<- 0.01
times<-seq(tinit,tfin,by=step)
funct<- function(t,integ,parms){  # the system of equations
  x<-integ[1]
  y<-integ[2]
  z<-integ[3]
  sigma<- parms[1]
  beta<- parms[2]
  rho<- parms[3]
  dx<- sigma*(y-x) # that is dx/dt = sigma(y-x)
  dy<- x*(rho-z)-y # that is dy/dt = x(rho-z)-y
  dz<- x*y-beta*z # that is dz/dt = xy -beta z
  list(c(dx,dy,dz))
} # end of funct
require(deSolve)
cinit<-c(1,1,1)
xyz<-lsoda(cinit,times,funct,parms)
# xyz # comment if you do not wish the xyz values printed
par(mfrow=c(3,1))
par(mar = c(4.3, 4.8, 1., 3))
par(cex.lab=1.5,cex.axis=1.2,lwd=1,lty=1)
plot(xyz[,1],xyz[,2],type="l",xlab="t",ylab="x(t)",  # x(t) vs t
     xlim=c(tinit,tfin),ylim=c(-30,30))
plot(xyz[,1],xyz[,3],type="l",xlab="t",ylab="y(t)",  # y(t) vs t
     xlim=c(tinit,tfin),ylim=c(-30,30))
plot(xyz[,1],xyz[,4],type="l",xlab="t",ylab="z(t)",  # z(t) vs t
     xlim=c(tinit,tfin),ylim=c(0 ,50))


# phase space portrait
require(scatterplot3d)
scatterplot3d(xyz[,2],xyz[,3],xyz[,4],type="l",
              cex.lab=1.4,cex.axis=1.2) 



